# StockHub
증권사 Open API Hub 서비스 입니다.

- 홈페이지 : https://invest.bluestones.biz/
- GitHub : https://www.npmjs.com/package/stockhub

​    

## 증권사 목록


|                   증권사                    |    시작일     |              Specification               |
| :--------------------------------------: | :--------: | :--------------------------------------: |
| [한국투자증권](https://apiportal.koreainvestment.com/intro) | 2022.04.11 | Swagger, JSON, [HTML](https://invest.bluestones.biz/cms/tradeStocks?action=openapi_spec&type=html), SQLite3 |
| [LS증권](https://openapi.ls-sec.co.kr/intro) | 2023.07.07 | Swagger, JSON, [HTML](https://invest.bluestones.biz/cms/tradeStocks?action=openapi_spec&type=html), SQLite3 |
| [DB증권](https://openapi.dbsec.co.kr/apiservice) | 2024.05.03 | Swagger, JSON, [HTML](https://invest.bluestones.biz/cms/tradeStocks?action=openapi_spec&type=html), SQLite3 |
|   [키움증권](https://openapi.kiwoom.com/)    | 2025.03.19 | Swagger, JSON, [HTML](https://invest.bluestones.biz/cms/tradeStocks?action=openapi_spec&type=html), SQLite3 |

- 오류 신고 : Reserved


  

## 개발 환경

- Node.js 22.14.0
  - TypeScript 5.8.2
- Python 3.12.9

  

## Libraries

- TypeScript
  - JavaScript, Java
- Python

```bash
#--- Node.js 라이브러리의 버전 확인
npm  outdated 
```
